pub struct RecoveryPlanner;Expand description
Finds the best checkpoint to use when recovering a failed job.
Implementations
Sourceimpl RecoveryPlanner
impl RecoveryPlanner
Sourcepub fn find_recovery_point<'a>(
store: &'a CheckpointStore,
failed_job_id: &str,
) -> Option<&'a Checkpoint>
pub fn find_recovery_point<'a>( store: &'a CheckpointStore, failed_job_id: &str, ) -> Option<&'a Checkpoint>
Find the most suitable recovery point for a failed job.
Returns the latest checkpoint for the given job, if any exists.