RaftNode

Struct RaftNode 

pub struct RaftNode {
    pub id: NodeId,
    pub role: RaftRole,
    pub current_term: RaftTerm,
    pub voted_for: Option<NodeId>,
    pub log: RaftLog,
    pub commit_index: u64,
    pub last_applied: u64,
}
A Raft consensus node.

Fields

id: NodeId

This node’s ID.

role: RaftRole

Current role.

current_term: RaftTerm

Latest term this node has seen.

voted_for: Option<NodeId>

NodeId this node voted for in the current term.

log: RaftLog

The replicated log.

commit_index: u64

Index of highest log entry known to be committed.

last_applied: u64

Index of highest log entry applied to state machine.

Implementations

Source

impl RaftNode

pub fn new(id: NodeId) -> Self

Create a new Raft node in Follower state.

pub fn process_vote_request(&mut self, req: &VoteRequest) -> VoteResponse

Process an incoming vote request and return a response.

Grant vote if:

  1. Candidate’s term >= our current term.
  2. We haven’t voted for anyone else this term.
  3. Candidate’s log is at least as up-to-date as ours.
pub fn become_candidate(&mut self)

Transition this node to Candidate and start a new election.

pub fn become_leader(&mut self)

Transition this node to Leader.

pub fn step_down(&mut self, new_term: RaftTerm)

Step down to Follower with a new term (e.g., after seeing higher term).