pub struct ConsistentHashRing { /* private fields */ }Expand description
Consistent hash ring for stable partition assignment.
Virtual nodes (vnodes) per physical node are proportional to weight.
Implementations
Sourceimpl ConsistentHashRing
impl ConsistentHashRing
Sourcepub fn add_node(&mut self, node: ClusterNode)
pub fn add_node(&mut self, node: ClusterNode)
Add a node to the ring.
Sourcepub fn remove_node(&mut self, node_id: &str)
pub fn remove_node(&mut self, node_id: &str)
Remove a node from the ring.
Sourcepub fn get_node(&self, key: &[u8]) -> Option<&ClusterNode>
pub fn get_node(&self, key: &[u8]) -> Option<&ClusterNode>
Look up the responsible node for a given key.
Sourcepub fn node_count(&self) -> usize
pub fn node_count(&self) -> usize
Return the number of physical nodes.
Sourcepub fn vnode_count(&self) -> usize
pub fn vnode_count(&self) -> usize
Return the total number of virtual nodes in the ring.