pub struct WorkloadBalancer;Expand description
Selects the best worker for a given task based on affinity and load.
Implementations
Sourceimpl WorkloadBalancer
impl WorkloadBalancer
Sourcepub fn assign_task(
workers: &[WorkerStatus],
requirements: &TaskRequirements,
) -> Option<NodeId>
pub fn assign_task( workers: &[WorkerStatus], requirements: &TaskRequirements, ) -> Option<NodeId>
Assign a task to the worker with the highest effective score.
Effective score = affinity × (1 - load_pct).
Returns None if no worker can satisfy the task requirements.