pub struct RetryPolicy {
pub max_retries: u32,
pub backoff: BackoffStrategy,
pub jitter: bool,
pub jitter_percent: u32,
pub retryable_codes: Vec<String>,
}Expand description
Configuration for retry behavior.
Fields
max_retries: u32Maximum number of retry attempts (0 = no retries).
backoff: BackoffStrategyBackoff strategy.
jitter: boolWhether to add jitter to computed delays.
jitter_percent: u32Maximum jitter percentage (0..100).
retryable_codes: Vec<String>Set of error codes that are retryable (empty = all errors are retryable).
Implementations
Sourceimpl RetryPolicy
impl RetryPolicy
Sourcepub fn new(max_retries: u32) -> Self
pub fn new(max_retries: u32) -> Self
Create a new retry policy with exponential backoff defaults.
Sourcepub fn with_backoff(self, backoff: BackoffStrategy) -> Self
pub fn with_backoff(self, backoff: BackoffStrategy) -> Self
Set the backoff strategy.
Sourcepub fn with_jitter(self, percent: u32) -> Self
pub fn with_jitter(self, percent: u32) -> Self
Enable jitter with the given percentage.
Sourcepub fn add_retryable_code(&mut self, code: &str)
pub fn add_retryable_code(&mut self, code: &str)
Add a retryable error code.
Sourcepub fn is_retryable(&self, code: &str) -> bool
pub fn is_retryable(&self, code: &str) -> bool
Check if an error code is retryable.
Sourcepub fn compute_delay(&self, attempt: u32) -> Duration
pub fn compute_delay(&self, attempt: u32) -> Duration
Compute the delay for the given attempt number (0-based).