pub enum DrainError {
WorkerNotFound(String),
AlreadyDraining(String),
NotDraining(String),
WorkerDraining(String),
}Expand description
Errors produced by the draining subsystem.
Variants
WorkerNotFound(String)
The worker ID is not registered.
AlreadyDraining(String)
An operation was attempted on a worker that is already draining.
NotDraining(String)
An operation was attempted on a worker that has not started draining.
WorkerDraining(String)
A task was submitted to a worker that is draining.