pub struct RaftNode {
pub id: NodeId,
pub role: RaftRole,
pub current_term: RaftTerm,
pub voted_for: Option<NodeId>,
pub log: RaftLog,
pub commit_index: u64,
pub last_applied: u64,
}Expand description
A Raft consensus node.
Fields
id: NodeIdThis node’s ID.
role: RaftRoleCurrent role.
current_term: RaftTermLatest term this node has seen.
voted_for: Option<NodeId>NodeId this node voted for in the current term.
log: RaftLogThe replicated log.
commit_index: u64Index of highest log entry known to be committed.
last_applied: u64Index of highest log entry applied to state machine.
Implementations
Sourceimpl RaftNode
impl RaftNode
Sourcepub fn process_vote_request(&mut self, req: &VoteRequest) -> VoteResponse
pub fn process_vote_request(&mut self, req: &VoteRequest) -> VoteResponse
Process an incoming vote request and return a response.
Grant vote if:
- Candidate’s term >= our current term.
- We haven’t voted for anyone else this term.
- Candidate’s log is at least as up-to-date as ours.
Sourcepub fn become_candidate(&mut self)
pub fn become_candidate(&mut self)
Transition this node to Candidate and start a new election.
Sourcepub fn become_leader(&mut self)
pub fn become_leader(&mut self)
Transition this node to Leader.